CacheControl class

Annotations
  • @immutable

Constructors

CacheControl({int? maxAge, int? maxStale, int? minFresh, bool noCache = false, bool noStore = false, bool noTransform = false, bool onlyIfCached = false, List<String> other = const []})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxAge → int?
final
maxStale → int?
final
minFresh → int?
final
noCache → bool
final
noStore → bool
final
noTransform → bool
final
onlyIfCached → bool
final
other → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited