DELETE class

Make a DELETE request

Inheritance
Annotations
  • @immutable

Constructors

DELETE(String path)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → String
HTTP request method which can be found in HttpMethod.
finalinherited
path → String
A relative or absolute path, or full URL of the endpoint.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited